@@ -3,6 +3,7 @@
 #
 import logging
 from pathlib import Path
+import sys
 
 import click
 from c7n.config import Config
@@ -13,6 +14,9 @@ from .core import CollectionRunner
 from .utils import load_policies
 
 
+log = logging.getLogger("c7n.iac")
+
+
 @click.group()
 def cli():
     """Shift Left Policy"""
@@ -26,7 +30,8 @@ def cli():
 @click.option("-d", "--directory", type=click.Path())
 @click.option("-o", "--output", default="cli", type=click.Choice(report_outputs.keys()))
 @click.option("--output-file", type=click.File("w"), default="-")
-def run(format, policy_dir, directory, output, output_file):
+@click.option("--output-query", default=None)
+def run(format, policy_dir, directory, output, output_file, output_query):
     """evaluate policies against IaC sources.
 
     WARNING - CLI interface subject to change.
@@ -36,18 +41,22 @@ def run(format, policy_dir, directory, output, output_file):
         policy_dir=Path(policy_dir),
         output=output,
         output_file=output_file,
+        output_query=output_query,
     )
     policies = load_policies(policy_dir, config)
+    if not policies:
+        log.warning("no policies found")
+        sys.exit(1)
     reporter = get_reporter(config)
     runner = CollectionRunner(policies, config, reporter)
-    runner.run()
+    sys.exit(int(runner.run()))
 
 
 if __name__ == "__main__":  # pragma: no cover
     try:
         cli()
     except Exception:
-        import pdb, sys, traceback
+        import pdb, traceback
 
         traceback.print_exc()
         pdb.post_mortem(sys.exc_info()[-1])
